@@ -19,6 +19,8 @@ import re
 from typing import (
     Dict,
     Mapping,
+    MutableMapping,
+    MutableSequence,
     Optional,
     AsyncIterable,
     Awaitable,
@@ -27,7 +29,8 @@ from typing import (
     Type,
     Union,
 )
-import pkg_resources
+
+from google.cloud.bigquery_storage_v1 import gapic_version as package_version
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -137,7 +140,7 @@ class BigQueryReadAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -173,9 +176,9 @@ class BigQueryReadAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, BigQueryReadTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the big query read client.
@@ -219,13 +222,13 @@ class BigQueryReadAsyncClient:
 
     async def create_read_session(
         self,
-        request: Union[storage.CreateReadSessionRequest, dict] = None,
+        request: Optional[Union[storage.CreateReadSessionRequest, dict]] = None,
         *,
-        parent: str = None,
-        read_session: stream.ReadSession = None,
-        max_stream_count: int = None,
+        parent: Optional[str] = None,
+        read_session: Optional[stream.ReadSession] = None,
+        max_stream_count: Optional[int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> stream.ReadSession:
         r"""Creates a new read session. A read session divides
@@ -279,7 +282,7 @@ class BigQueryReadAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_storage_v1.types.CreateReadSessionRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_storage_v1.types.CreateReadSessionRequest, dict]]):
                 The request object. Request message for
                 `CreateReadSession`.
             parent (:class:`str`):
@@ -382,12 +385,12 @@ class BigQueryReadAsyncClient:
 
     def read_rows(
         self,
-        request: Union[storage.ReadRowsRequest, dict] = None,
+        request: Optional[Union[storage.ReadRowsRequest, dict]] = None,
         *,
-        read_stream: str = None,
-        offset: int = None,
+        read_stream: Optional[str] = None,
+        offset: Optional[int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Awaitable[AsyncIterable[storage.ReadRowsResponse]]:
         r"""Reads rows from the stream in the format prescribed
@@ -427,7 +430,7 @@ class BigQueryReadAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_storage_v1.types.ReadRowsRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_storage_v1.types.ReadRowsRequest, dict]]):
                 The request object. Request message for `ReadRows`.
             read_stream (:class:`str`):
                 Required. Stream to read rows from.
@@ -513,10 +516,10 @@ class BigQueryReadAsyncClient:
 
     async def split_read_stream(
         self,
-        request: Union[storage.SplitReadStreamRequest, dict] = None,
+        request: Optional[Union[storage.SplitReadStreamRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> storage.SplitReadStreamResponse:
         r"""Splits a given ``ReadStream`` into two ``ReadStream`` objects.
@@ -560,7 +563,7 @@ class BigQueryReadAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.bigquery_storage_v1.types.SplitReadStreamRequest, dict]):
+            request (Optional[Union[google.cloud.bigquery_storage_v1.types.SplitReadStreamRequest, dict]]):
                 The request object. Request message for
                 `SplitReadStream`.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -618,14 +621,9 @@ class BigQueryReadAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-bigquery-storage",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BigQueryReadAsyncClient",)
