@@ -19,6 +19,8 @@ import re
 from typing import (
     Dict,
     Mapping,
+    MutableMapping,
+    MutableSequence,
     Optional,
     Iterable,
     Iterator,
@@ -26,8 +28,10 @@ from typing import (
     Tuple,
     Type,
     Union,
+    cast,
 )
-import pkg_resources
+
+from google.cloud.bigquery_storage_v1beta2 import gapic_version as package_version
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -68,7 +72,7 @@ class BigQueryWriteClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[BigQueryWriteTransport]:
         """Returns an appropriate transport class.
 
@@ -314,7 +318,7 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -369,8 +373,8 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, BigQueryWriteTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, BigQueryWriteTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the big query write client.
@@ -384,7 +388,7 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
             transport (Union[str, BigQueryWriteTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -414,6 +418,7 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -466,12 +471,12 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def create_write_stream(
         self,
-        request: Union[storage.CreateWriteStreamRequest, dict] = None,
+        request: Optional[Union[storage.CreateWriteStreamRequest, dict]] = None,
         *,
-        parent: str = None,
-        write_stream: stream.WriteStream = None,
+        parent: Optional[str] = None,
+        write_stream: Optional[stream.WriteStream] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> stream.WriteStream:
         r"""Creates a write stream to the given table. Additionally, every
@@ -584,10 +589,10 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def append_rows(
         self,
-        requests: Iterator[storage.AppendRowsRequest] = None,
+        requests: Optional[Iterator[storage.AppendRowsRequest]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> Iterable[storage.AppendRowsResponse]:
         r"""Appends data to the given stream.
@@ -684,11 +689,11 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def get_write_stream(
         self,
-        request: Union[storage.GetWriteStreamRequest, dict] = None,
+        request: Optional[Union[storage.GetWriteStreamRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> stream.WriteStream:
         r"""Gets a write stream.
@@ -787,11 +792,11 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def finalize_write_stream(
         self,
-        request: Union[storage.FinalizeWriteStreamRequest, dict] = None,
+        request: Optional[Union[storage.FinalizeWriteStreamRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> storage.FinalizeWriteStreamResponse:
         r"""Finalize a write stream so that no new data can be appended to
@@ -888,11 +893,11 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def batch_commit_write_streams(
         self,
-        request: Union[storage.BatchCommitWriteStreamsRequest, dict] = None,
+        request: Optional[Union[storage.BatchCommitWriteStreamsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> storage.BatchCommitWriteStreamsResponse:
         r"""Atomically commits a group of ``PENDING`` streams that belong to
@@ -996,11 +1001,11 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
 
     def flush_rows(
         self,
-        request: Union[storage.FlushRowsRequest, dict] = None,
+        request: Optional[Union[storage.FlushRowsRequest, dict]] = None,
         *,
-        write_stream: str = None,
+        write_stream: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> storage.FlushRowsResponse:
         r"""Flushes rows to a BUFFERED stream. If users are appending rows
@@ -1100,7 +1105,7 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "BigQueryWriteClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1114,14 +1119,9 @@ class BigQueryWriteClient(metaclass=BigQueryWriteClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-bigquery-storage",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("BigQueryWriteClient",)
